@@ -913,24 +913,29 @@ class BlobStore2(object):
         """Multi platform handle for chif hprest library"""
         excp = None
         libhandle = None
-        libnames = (
-            ["ilorest_chif.dll", "hprest_chif.dll"]
-            if os.name == "nt"
-            else [
-                "ilorest_chif_dev.so",
-                "hprest_chif_dev.so",
-                "ilorest_chif.so",
-                "hprest_chif.so",
-            ]
-        )
-        for libname in libnames:
-            try:
-                libpath = BlobStore2.checkincurrdirectory(libname)
+        if os.name != "nt":
+            libpath = '/opt/ilorest/lib64/libilorestchif.so'
+            if os.path.isfile(libpath):
                 libhandle = cdll.LoadLibrary(libpath)
-                if libhandle:
-                    break
-            except Exception as exp:
-                excp = exp
+        if not libhandle:
+            libnames = (
+                ["ilorest_chif.dll"]
+                if os.name == "nt"
+                else [
+                    "ilorest_chif_dev.so",
+                    "ilorest_chif.so",
+                ]
+            )
+            for libname in libnames:
+                try:
+                    libpath = BlobStore2.checkincurrdirectory(libname)
+                    #LOGGER.debug("Loading Library %s for libhpsrv", libpath)
+                    libhandle = cdll.LoadLibrary(libpath)
+                    if libhandle:
+                        #LOGGER.debug("Got Libhandle %s for libhpsrv", libhandle)
+                        break
+                except Exception as exp:
+                    excp = exp
 
         if libhandle:
             BlobStore2.setglobalhprestchifrandnumber(libhandle)
@@ -955,9 +960,11 @@ class BlobStore2(object):
         :param password: The password to login.
         :type password: str.
         """
+
         dll = BlobStore2.gethprestchifhandle()
         if LOGGER.isEnabledFor(logging.DEBUG):
             dll.enabledebugoutput()
+        #LOGGER.debug("Calling ChifInitialize...")
         dll.ChifInitialize(None)
         if username:
             if not password:
@@ -969,7 +976,9 @@ class BlobStore2(object):
                 usernew = create_string_buffer(username.encode("utf-8"))
                 passnew = create_string_buffer(password.encode("utf-8"))
 
+                #LOGGER.debug("Calling initiate_credentials...")
                 dll.initiate_credentials(usernew, passnew)
+                #LOGGER.debug("Calling ChifVerifyCredentials...")
                 credreturn = dll.ChifVerifyCredentials()
                 if not credreturn == BlobReturnCodes.SUCCESS:
                     if credreturn == hpiloreturncodes.CHIFERR_AccessDenied:
@@ -983,9 +992,11 @@ class BlobStore2(object):
                 dll.ChifDisableSecurity()
         else:
             # if high security return False
+            #LOGGER.debug("Calling ChifIsSecurityRequired...")
             if dll.ChifIsSecurityRequired() > 0:
                 return False
             else:
+                #LOGGER.debug("Calling ChifDisableSecurity...")
                 dll.ChifDisableSecurity()
 
         BlobStore2.unloadchifhandle(dll)
